@@ -1,13 +1,13 @@
 
-import version
+from . import version
 
 VERSION = version.VERSION
 __version__ = VERSION
 
 
-from api import Request, File
-from api import init, api_key, base_url
-from api import get_filters, apply_image_filters
+from .api import Request, File
+from .api import init, api_key, base_url
+from .api import get_filters, apply_image_filters
 
 import logging
 try:
@@ -18,4 +18,4 @@ except ImportError:
         def emit(self, record):
             pass
 
-logging.getLogger(__name__).addHandler(NullHandler())
\ No newline at end of file
+logging.getLogger(__name__).addHandler(NullHandler())
